@@ -1,6 +1,7 @@
 import inspect
 import json
 import logging
+import os
 
 import numpy as np
 from pathlib import Path
@@ -10,7 +11,6 @@ from autoconf.class_path import get_class_path, get_class
 
 logger = logging.getLogger(__name__)
 
-
 np_type_map = {
     "bool": "bool_",
 }
@@ -47,7 +47,29 @@ def is_array(obj) -> bool:
         return False
 
 
+def compound_key_dict(obj):
+    """
+    Converts a dictionary with compound keys to a dictionary with a single key.
+    """
+    return {
+        "type": "compound_dict",
+        "arguments": [
+            {
+                "key": to_dict(key),
+                "value": to_dict(value),
+            }
+            for key, value in obj.items()
+        ],
+    }
+
+
 def to_dict(obj, filter_args: Tuple[str, ...] = ()) -> dict:
+    if hasattr(obj, "dict"):
+        try:
+            return obj.dict()
+        except TypeError as e:
+            logger.debug(e)
+
     if isinstance(obj, (int, float, str, bool, type(None))):
         return obj
 
@@ -72,12 +94,6 @@ def to_dict(obj, filter_args: Tuple[str, ...] = ()) -> dict:
             "class_path": obj.__module__ + "." + obj.__qualname__,
         }
 
-    if hasattr(obj, "dict"):
-        try:
-            return obj.dict()
-        except TypeError as e:
-            logger.debug(e)
-
     if is_array(obj):
         try:
             return nd_array_as_dict(obj)
@@ -101,6 +117,12 @@ def to_dict(obj, filter_args: Tuple[str, ...] = ()) -> dict:
     if isinstance(obj, tuple):
         return {"type": "tuple", "values": list(map(to_dict, obj))}
     if isinstance(obj, dict):
+        if any(
+            not (isinstance(key, (str, int, float, bool)) or key is None)
+            for key in obj.keys()
+        ):
+            return compound_key_dict(obj)
+
         return {
             "type": "dict",
             "arguments": {
@@ -109,6 +131,7 @@ def to_dict(obj, filter_args: Tuple[str, ...] = ()) -> dict:
                 if key not in filter_args
             },
         }
+
     if obj.__class__.__name__ == "method":
         return to_dict(obj())
     if obj.__class__.__module__ == "builtins":
@@ -297,7 +320,15 @@ def from_dict(dictionary, **kwargs):
     if type_ == "tuple":
         return tuple(map(from_dict, dictionary["values"]))
     if type_ == "dict":
-        return {key: from_dict(value, **kwargs) for key, value in dictionary.items()}
+        return {
+            key: from_dict(value, **kwargs)
+            for key, value in dictionary["arguments"].items()
+        }
+    if type_ == "compound_dict":
+        return {
+            from_dict(item["key"], **kwargs): from_dict(item["value"], **kwargs)
+            for item in dictionary["arguments"]
+        }
 
     if type_ == "type":
         return get_class(dictionary["class_path"])
@@ -348,5 +379,9 @@ def output_to_json(obj, file_path: Union[Path, str]):
     file_path
         The path to the .json file that the dictionary representation of the object is written too.
     """
+    file_path = Path(file_path)
+    file_dir = Path(*file_path.parts[:-1])
+    file_dir.mkdir(parents=True, exist_ok=True)
+
     with open(file_path, "w+") as f:
         json.dump(to_dict(obj), f, indent=4)
